# -*- coding: utf-8 -*-
# Copyright 2007-2024 The eXSpy developers
#
# This file is part of eXSpy.
#
# eXSpy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# eXSpy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with eXSpy. If not, see <https://www.gnu.org/licenses/#GPL>.

import hyperspy.api as hs

import exspy


def test_dielectric_function_binned_default():
    s = exspy.signals.DielectricFunction([0])
    assert not s.axes_manager[-1].is_binned


def test_signal_binned_default():
    s = hs.signals.BaseSignal([0])
    assert not s.axes_manager[-1].is_binned


def test_eels_spectrum_binned_default():
    s = exspy.signals.EELSSpectrum([0])
    assert s.axes_manager[-1].is_binned


def test_eds_tem_binned_default():
    s = exspy.signals.EDSTEMSpectrum([0])
    assert s.axes_manager[-1].is_binned


def test_eds_sem_binned_default():
    s = exspy.signals.EDSSEMSpectrum([0])
    assert s.axes_manager[-1].is_binned



# Deprecated and to be removed in exspy 1.0

import warnings

from hyperspy.exceptions import VisibleDeprecationWarning

from exspy.utils.eels import (
    iMFP_angular_correction,
    iMFP_Iakoubovskii,
    iMFP_TPP2M,
)

__all__ = [
    "iMFP_angular_correction",
    "iMFP_Iakoubovskii",
    "iMFP_TPP2M",
]


warnings.warn(
    "This module is deprecated, use `exspy.utils.eels` instead. "
    "It will be removed in exspy 1.0.",
    VisibleDeprecationWarning,
)



# Deprecated and to be removed in exspy 1.0

import warnings

from hyperspy.exceptions import VisibleDeprecationWarning

from exspy._misc.elements import elements_db


__all__ = [
    "elements_db",
]


def __dir__():
    return sorted(__all__)


warnings.warn(
    "This module is deprecated, use `exspy.material` instead. "
    "It will be removed in exspy 1.0.",
    VisibleDeprecationWarning,
)



# -*- coding: utf-8 -*-
# Copyright 2007-2024 The eXSpy developers
#
# This file is part of eXSpy.
#
# eXSpy is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# eXSpy is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with eXSpy. If not, see <https://www.gnu.org/licenses/#GPL>.

from ._misc.material import (
    atomic_to_weight,
    density_of_mixture,
    mass_absorption_coefficient,
    mass_absorption_mixture,
    weight_to_atomic,
)
from ._misc.elements import elements_db as elements


__all__ = [
    "atomic_to_weight",
    "density_of_mixture",
    "elements",
    "mass_absorption_coefficient",
    "mass_absorption_mixture",
    "weight_to_atomic",
]


def __dir__():
    return sorted(__all__)



# ruff: noqa
# Remove in exspy 1.0

import pytest

from hyperspy.exceptions import VisibleDeprecationWarning


def test_import_element():
    with pytest.warns(VisibleDeprecationWarning) as record:
        from exspy.misc.elements import elements_db

    assert "use `exspy.material` instead" in record[0].message.args[0]


def test_import_material():
    with pytest.warns(VisibleDeprecationWarning) as record:
        from exspy.misc.material import (
            atomic_to_weight,
            density_of_mixture,
            mass_absorption_coefficient,
            mass_absorption_mixture,
            weight_to_atomic,
        )

    assert "use `exspy.material` instead" in record[0].message.args[0]


def test_import_eds_utils():
    with pytest.warns(VisibleDeprecationWarning) as record:
        from exspy.misc.eds.utils import (
            cross_section_to_zeta,
            electron_range,
            get_xray_lines_near_energy,
            take_off_angle,
            xray_range,
            zeta_to_cross_section,
        )

    assert "use `exspy.utils.eds` instead" in record[0].message.args[0]


def test_import_eels_tools():
    with pytest.warns(VisibleDeprecationWarning) as record:
        from exspy.misc.eels.tools import (
            effective_angle,
            get_edges_near_energy,
            get_info_from_edges,
        )

    assert "use `exspy.utils.eels` instead" in record[0].message.args[0]


def test_import_eels_electron_inelastic_mean_free_path():
    with pytest.warns(VisibleDeprecationWarning) as record:
        from exspy.misc.eels.electron_inelastic_mean_free_path import (
            iMFP_angular_correction,
            iMFP_Iakoubovskii,
            iMFP_TPP2M,
        )

    assert "use `exspy.utils.eels` instead" in record[0].message.args[0]
